@@ -1,7 +1,9 @@
 csMCA <- function(data,subcloud=rep(TRUE,times=nrow(data)),excl=NULL,ncp=5,row.w=rep(1,times=nrow(data))) {
     data <- as.data.frame(data)
+    for(i in 1:ncol(data)) data[,i] <- factor(data[,i])
     row.w <- row.w/sum(row.w)*nrow(data)
     row.wc <- row.w[subcloud]
+    if(is.character(excl)) excl <- which(getindexcat(data) %in% excl)
     if(is.null(excl)) excl <- 99999
     N <- nrow(data)
     n <- nrow(data[subcloud,])
@@ -41,11 +43,10 @@ csMCA <- function(data,subcloud=rep(TRUE,times=nrow(data)),excl=NULL,ncp=5,row.w
     weight <- n*fK
     coord <- YIpc[,1:ncp]
     contrib <- 100*row.wc/n.w*coord*coord/matrix(rep(eig[[1]][1:ncp],times=n),ncol=ncp,nrow=n,byrow=T)
-    dimnames(coord) <- list(rownames(data)[subcloud],dims) # new
-    dimnames(contrib) <- list(rownames(data)[subcloud],dims) # new
+    dimnames(coord) <- list(rownames(data)[subcloud],dims) 
+    dimnames(contrib) <- list(rownames(data)[subcloud],dims) 
     ind <- list(coord=coord,contrib=round(contrib,6))
     coord <- YKc[,1:ncp]
-    #Vspe <- sum(fK*(1-fK)/FK)/Q
     contrib <- 100*(FK/Q)*coord*coord/matrix(rep(eig[[1]][1:ncp],times=Kp),ncol=ncp,nrow=Kp,byrow=T)
     s <- vector()
     for(i in 1:Q) s <- c(s,rep(i,times=length(levels(data[,i]))))
@@ -70,8 +71,8 @@ csMCA <- function(data,subcloud=rep(TRUE,times=nrow(data)),excl=NULL,ncp=5,row.w
     marge.row <- rep(1/(n.w*Q),times=n)
     names(marge.row) <- 1:n
     quali <- 1:Q
-    call <- list(X=data,marge.col=marge.col,marge.row=marge.row,ncp=ncp,quali=quali,subcloud=subcloud,excl=excl,row.w=row.w)
+    call <- list(X=data,marge.col=marge.col,marge.row=marge.row,ncp=ncp,quali=quali,subcloud=subcloud,excl=excl,excl.char=getindexcat(data)[excl],row.w=row.w)
     RES <- list(eig=eig,call=call,ind=ind,var=var,svd=list(vs=svd$d,U=svd$u,V=svd$v))
-    attr(RES,'class') <- c('csMCA','list')
+    attr(RES,'class') <- c('csMCA','speMCA','list')
     RES
 }
